﻿using Syncfusion.SfCalendar.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Text;
using Xamarin.Forms;

namespace MonthCellTemplate
{
    class CalendarBehavior : Behavior<ContentPage>
    {
        SfCalendar calendar;
        bool enableSelection = false;
        ViewModel viewModel;
        protected override void OnAttachedTo(ContentPage bindable)
        {
            base.OnAttachedTo(bindable);
            calendar = bindable.FindByName<SfCalendar>("calendar");
            calendar.SelectedDate = null;
            calendar.OnMonthCellLoaded += Calendar_OnMonthCellLoaded;
            calendar.SelectionChanged += Calendar_SelectionChanged;
            viewModel = (ViewModel)bindable.BindingContext;
        }

        private void Calendar_SelectionChanged(object sender, Syncfusion.SfCalendar.XForms.SelectionChangedEventArgs e)
        {
            this.enableSelection = true;  
        }

        private void Calendar_OnMonthCellLoaded(object sender, MonthCellLoadedEventArgs e)
        {
            var dataTemplate = GetDayModelFor(e.Date, calendar);
                e.CellBindingContext = dataTemplate;
        }

        public CalendarViewModel GetDayModelFor(DateTime date, SfCalendar calendar)
        {
            var selectedDate = DateTime.Now;
            if (calendar.SelectedDate != null)
            {
                selectedDate = (DateTime)calendar.SelectedDate;
            }

            var selected = false;
            if (calendar.SelectedDate != null && date.Month == selectedDate.Month &&
                                     date.Year == selectedDate.Year && date.Day == selectedDate.Day)
            {
                selected = true;
            }
           

            bool isScheduleDate = false;
            if(!selected)
            {
                foreach (var item in viewModel.Dates)
                {
                    if (item.Month == date.Month &&
                                     item.Year == date.Year && item.Day == date.Day)
                    {
                        isScheduleDate = true;
                        break;
                    }
                }
            }
            bool today= date.Day == DateTime.Today.Day &&
                              date.Month == DateTime.Today.Month &&
                              date.Year == DateTime.Today.Year;
            return new CalendarViewModel()
            {
                Calendar = calendar,
                Date = date.Date,
                IsToday = today,
                IsSelected = selected,
                SelectedTextColor = selected?Color.White:today?Color.Red: Color.Black,
                IsScheduled = isScheduleDate
            };

        }
    }
}
    
